FormGroup<TControls extends ControlsCollection> class

Inheritance

Constructors

FormGroup(TControls controls, {OptionsFormGroup<TControls>? options})

Properties

active → bool
Error checking enabled Проверка ошибок включена
no setterinherited
additionalData ↔ dynamic
Field for transferring additional information Поле для передачи дополнительной информации (в логике не участвует)
getter/setter pairinherited
controls → TControls
finalinherited
dirty → bool
Value changed Значение изменялось
no setterinherited
disabled → bool
Error checking is disabled (control is always valid) Проверка ошибок отключена (контрол всегда валиден)
no setterinherited
errors → List<ValidationEvent>
Errors list Список ошибок
no setterinherited
focused → bool
The field is now in focus Поле сейчас в фокусе
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
informationMessages → List<ValidationEvent>
Informations messages list Сообщения с типом "Информационные сообщения"
no setterinherited
inProcessing ↔ bool
getter/setter pairinherited
invalid → bool
Invalid Невалидные данные
no setterinherited
maxEventLevel → ValidationEventTypes
Max message level Максимальный уровень сообщения
no setterinherited
onChange ↔ StreamController<AbstractControl>
Callback function of on change Сообщает факт изменения данных
getter/setter pairinherited
pristine → bool
The value has not changed Значение не изменялось
no setterinherited
processing → bool
Validation in progress В процессе анализа
no setterinherited
reactionOnValidatorDisposers ↔ List<ReactionDisposer>
getter/setter pairinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
serverErrors ↔ ObservableList<String>
Additional (server) errors Дополнительтные (серверные) ошибки
getter/setter pairinherited
successes → List<ValidationEvent>
Successes messages list Сообщения с типом "успешная валидация"
no setterinherited
touched → bool
The field was in focus Поле было в фокусе
no setterinherited
type → ControlTypes
Type Тип контрола
finalinherited
untouched → bool
The field was out of focus Поле не было в фокусе
no setterinherited
valid → bool
Valid Валидные данные
no setterinherited
warnings → List<ValidationEvent>
Warnings messages list Список сообщений с типом "Внимание"
no setterinherited

Methods

allControls() → List<FormControl>
Returns a complete list of FormControls without subgroups (terminal elements) Возвращает полный список FormControl-ов без вложений (терминальные элементы)
inherited
baseExecuteAsyncValidation<TAbstractControl extends AbstractControl>(ValidatorsFunction<TAbstractControl> validator, Function onValidationFunction) → Future<List<ValidationEvent>>
inherited
dispose() → void
Dispose (call in unmount react control) Вызвать при удалении контрола
inherited
error(String key) → ValidationEvent?
Get error by key Получить ошибку по ключу
inherited
executeAsyncValidation<TAbstractControl extends AbstractControl>(ValidatorsFunction<TAbstractControl> validator) → Future<List<ValidationEvent>>
inherited
getControls() → Iterable<AbstractControl>
inherited
hasErrors() → bool
The field contains errors Присутствуют ошибки
inherited
hasInformationMessages() → bool
The field contains informations messages Присутствуют сообщения с типом "Информационные сообщения"
inherited
hasSuccesses() → bool
The field contains successes Присутствуют сообщения с типом "успешная валидация"
inherited
hasWarnings() → bool
The field contains warnings messages Присутствуют сообщения с типом "Внимание"
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onValidation<TAbstractControl extends AbstractControl>({required List<ValidatorsFunction<TAbstractControl>> validators, required dynamic onCompleter(Completer<List<ValidationEvent>> completer, ValidatorsFunction<TAbstractControl> validator), required Function onValidationFunction, required Function afterCheck}) → dynamic
inherited
runInAction(Function action) → void
inherited
setDirty(bool dirty) → AbstractControl
Set marker "Value has changed" Установить маркер "Значение изменилось"
inherited
setTouched(bool touched) → AbstractControl
Set marker "field was in focus" Установить маркер "Поле было в фокусе"
inherited
toString() → String
A string representation of this object.
inherited
wait() → Future
Waiting for end of validation Ожидание окончания проверки
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited